# metashape ![Python package](https://github.com/podhmo/metashape/workflows/Python%20package/badge.svg) [![PyPi version](https://img.shields.io/pypi/v/metashape.svg)](https://pypi.python.org/pypi/metashape) [![](https://img.shields.io/badge/python-3.7+-blue.svg)](https://www.python.org/download/releases/3.7.0/) [![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://black.readthedocs.io/en/stable/)

:construction: this project is under construction :construction:

## installing

```console
$ pip install metashape[cli]
```
